@@ -310,7 +310,7 @@ def join_files_walker(arguments, directory_name, names):
     # tries to run the handle ignore operation for the current set of names and
     # in case there's a processing returns the control flow immediately as no
     # more handling is meant to occur for the current operation (ignored)
-    if extra.handle_ignore(names):
+    if extra.handle_ignore(directory_name, names, token="join"):
         return
 
     # removes the complete set of names that are meant to be excluded from the
